@@ -64,7 +64,6 @@ var searchData=
   ['sequenceinputstream_2eidl',['SequenceInputStream.idl',['../SequenceInputStream_8idl.html',1,'']]],
   ['sequenceoutputstream_2eidl',['SequenceOutputStream.idl',['../SequenceOutputStream_8idl.html',1,'']]],
   ['sequencetimecontainer_2eidl',['SequenceTimeContainer.idl',['../SequenceTimeContainer_8idl.html',1,'']]],
-  ['serialnumberadapter_2eidl',['SerialNumberAdapter.idl',['../SerialNumberAdapter_8idl.html',1,'']]],
   ['servicemanager_2eidl',['ServiceManager.idl',['../ServiceManager_8idl.html',1,'']]],
   ['servicenotfoundexception_2eidl',['ServiceNotFoundException.idl',['../ServiceNotFoundException_8idl.html',1,'']]],
   ['servicenotregisteredexception_2eidl',['ServiceNotRegisteredException.idl',['../ServiceNotRegisteredException_8idl.html',1,'']]],
@@ -109,6 +108,7 @@ var searchData=
   ['simplesetaccess_2eidl',['SimpleSetAccess.idl',['../SimpleSetAccess_8idl.html',1,'']]],
   ['simplesetupdate_2eidl',['SimpleSetUpdate.idl',['../SimpleSetUpdate_8idl.html',1,'']]],
   ['simplesystemmail_2eidl',['SimpleSystemMail.idl',['../SimpleSystemMail_8idl.html',1,'']]],
+  ['simpletextformatter_2eidl',['SimpleTextFormatter.idl',['../SimpleTextFormatter_8idl.html',1,'']]],
   ['singlebackend_2eidl',['SingleBackend.idl',['../SingleBackend_8idl.html',1,'']]],
   ['singlebackendadapter_2eidl',['SingleBackendAdapter.idl',['../SingleBackendAdapter_8idl.html',1,'']]],
   ['singlelayerstratum_2eidl',['SingleLayerStratum.idl',['../SingleLayerStratum_8idl.html',1,'']]],
